@@ -111,9 +111,8 @@ conn_get_default_alias (TpBaseConnection *base,
   const url_t *url;
   gchar *alias = NULL;
 
-  /* TODO: create our custom handle repo to be able to get the URL off it.
-   * Then we can reuse the contact_handles parameter */
-  url = rakia_handle_inspect_uri (base, handle);
+  url = rakia_base_connection_handle_to_uri (RAKIA_BASE_CONNECTION (base),
+      handle);
 
   switch (url->url_type)
     {
@@ -314,7 +313,7 @@ rakia_connection_set_aliases (TpSvcConnectionInterfaceAliasing *iface,
   if (alias == NULL || g_hash_table_size (aliases) > 1)
     {
       /* One of the handles (if there are any) cannot be the self handle */
-      GError err = { TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+      GError err = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
           "Cannot set aliases for any contact except self" };
       dbus_g_method_return_error (context, &err);
       return;
