@@ -17,6 +17,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include "config.h"
+
 #include "debug.h"
 
 #include <glib.h>
@@ -47,7 +49,8 @@ static GString *sofia_log_buf = NULL;
 static void rakia_sofia_log_close (void);
 
 
-void rakia_debug_set_flags_from_env ()
+void
+rakia_debug_set_flags_from_env (void)
 {
   const gchar *flags_string;
 
