@@ -381,8 +381,6 @@ incoming_call_cb (RakiaSipSession *session,
     struct InviteData *idata)
 {
   RakiaCallChannel *channel;
-  RakiaMediaManagerPrivate *priv =
-      RAKIA_MEDIA_MANAGER_GET_PRIVATE (idata->fac);
 
   g_signal_handlers_disconnect_by_func (session,
       G_CALLBACK (incoming_call_cb), idata);
@@ -394,7 +392,6 @@ incoming_call_cb (RakiaSipSession *session,
       TP_EXPORTABLE_CHANNEL (channel), NULL);
 
   g_object_unref (session);
-  rakia_handle_unref (priv->conn, idata->handle);
   g_slice_free (struct InviteData, idata);
 }
 
@@ -647,7 +644,7 @@ rakia_media_manager_requestotron (TpChannelManager *manager,
    * Call channel type */
   if (handle == conn->self_handle)
     {
-      g_set_error (&error, TP_ERRORS, TP_ERROR_NOT_IMPLEMENTED,
+      g_set_error (&error, TP_ERROR, TP_ERROR_NOT_IMPLEMENTED,
           "Cannot call self");
       goto error;
     }
