@@ -74,6 +74,7 @@ G_DEFINE_TYPE_WITH_CODE (RakiaTextChannel, rakia_text_channel, G_TYPE_OBJECT,
 
 static const char *rakia_text_channel_interfaces[] = {
     TP_IFACE_CHANNEL_INTERFACE_DESTROYABLE,
+    TP_IFACE_CHANNEL_INTERFACE_MESSAGES,
     NULL
 };
 
@@ -131,8 +132,8 @@ struct _RakiaTextChannelPrivate
 
 #define RAKIA_TEXT_CHANNEL_GET_PRIVATE(o)     (G_TYPE_INSTANCE_GET_PRIVATE ((o), RAKIA_TYPE_TEXT_CHANNEL, RakiaTextChannelPrivate))
 
-static void rakia_text_pending_free (RakiaTextPendingMessage *msg,
-                                     TpHandleRepoIface *contact_handles)
+static void
+rakia_text_pending_free (RakiaTextPendingMessage *msg)
 {
   if (msg->nh)
     nua_handle_unref (msg->nh);
@@ -161,7 +162,6 @@ rakia_text_channel_constructed (GObject *obj)
 {
   RakiaTextChannelPrivate *priv;
   TpBaseConnection *base_conn;
-  TpHandleRepoIface *contact_handles;
   TpDBusDaemon *bus;
   TpChannelTextMessageType types[] = {
       TP_CHANNEL_TEXT_MESSAGE_TYPE_NORMAL,
@@ -178,13 +178,8 @@ rakia_text_channel_constructed (GObject *obj)
 
   priv = RAKIA_TEXT_CHANNEL_GET_PRIVATE(RAKIA_TEXT_CHANNEL(obj));
   base_conn = (TpBaseConnection *) priv->conn;
-  contact_handles = tp_base_connection_get_handles (base_conn,
-      TP_HANDLE_TYPE_CONTACT);
-
-  tp_handle_ref (contact_handles, priv->handle);
 
   g_assert (priv->initiator != 0);
-  tp_handle_ref (contact_handles, priv->initiator);
 
   rakia_base_connection_add_auth_handler (priv->conn, RAKIA_EVENT_TARGET (obj));
 
@@ -452,7 +447,6 @@ rakia_text_channel_dispose(GObject *object)
 {
   RakiaTextChannel *self = RAKIA_TEXT_CHANNEL (object);
   RakiaTextChannelPrivate *priv = RAKIA_TEXT_CHANNEL_GET_PRIVATE (self);
-  TpHandleRepoIface *contact_handles;
 
   if (priv->dispose_has_run)
     return;
@@ -465,24 +459,15 @@ rakia_text_channel_dispose(GObject *object)
       tp_svc_channel_emit_closed (self);
     }
 
-  contact_handles = tp_base_connection_get_handles (
-      (TpBaseConnection *) priv->conn, TP_HANDLE_TYPE_CONTACT);
-
-  tp_handle_unref (contact_handles, priv->handle);
-
-  if (priv->initiator != 0)
-    tp_handle_unref (contact_handles, priv->initiator);
-
   if (G_OBJECT_CLASS (rakia_text_channel_parent_class)->dispose)
     G_OBJECT_CLASS (rakia_text_channel_parent_class)->dispose (object);
 }
 
 static void
-zap_pending_messages (GQueue *pending_messages,
-                      TpHandleRepoIface *contact_handles)
+zap_pending_messages (GQueue *pending_messages)
 {
   g_queue_foreach (pending_messages,
-      (GFunc) rakia_text_pending_free, contact_handles);
+      (GFunc) rakia_text_pending_free, NULL);
   g_queue_clear (pending_messages);
 }
 
@@ -491,14 +476,10 @@ rakia_text_channel_finalize(GObject *object)
 {
   RakiaTextChannel *self = RAKIA_TEXT_CHANNEL (object);
   RakiaTextChannelPrivate *priv = RAKIA_TEXT_CHANNEL_GET_PRIVATE (self);
-  TpHandleRepoIface *contact_handles;
-
-  contact_handles = tp_base_connection_get_handles (
-      (TpBaseConnection *)priv->conn, TP_HANDLE_TYPE_CONTACT);
 
   DEBUG ("%u pending outgoing message requests",
       g_queue_get_length (priv->sending_messages));
-  zap_pending_messages (priv->sending_messages, contact_handles);
+  zap_pending_messages (priv->sending_messages);
   g_queue_free (priv->sending_messages);
 
   g_free (priv->object_path);
@@ -548,15 +529,10 @@ rakia_text_channel_close (TpSvcChannel *iface,
 
           if (priv->initiator != priv->handle)
             {
-              TpHandleRepoIface *contact_repo = tp_base_connection_get_handles
-                  ((TpBaseConnection *) priv->conn, TP_HANDLE_TYPE_CONTACT);
-
               g_assert (priv->initiator != 0);
               g_assert (priv->handle != 0);
 
-              tp_handle_unref (contact_repo, priv->initiator);
               priv->initiator = priv->handle;
-              tp_handle_ref (contact_repo, priv->initiator);
             }
         }
       tp_svc_channel_emit_closed (self);
@@ -657,7 +633,7 @@ rakia_text_channel_send_message (GObject *object,
 #define INVALID_ARGUMENT(msg, ...) \
   G_STMT_START { \
     DEBUG (msg , ## __VA_ARGS__); \
-    g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT, \
+    g_set_error (&error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT, \
         msg , ## __VA_ARGS__); \
     goto fail; \
   } G_STMT_END
@@ -692,7 +668,7 @@ rakia_text_channel_send_message (GObject *object,
   msg_nh = rakia_base_connection_create_handle (priv->conn, priv->handle);
   if (msg_nh == NULL)
     {
-      g_set_error (&error, TP_ERRORS, TP_ERROR_NOT_AVAILABLE,
+      g_set_error (&error, TP_ERROR, TP_ERROR_NOT_AVAILABLE,
           "Request creation failed");
       goto fail;
     }
@@ -761,10 +737,9 @@ delivery_report (RakiaTextChannel *self,
 
   base_conn = (TpBaseConnection *) priv->conn;
 
-  msg = tp_message_new (base_conn, 1, 1);
+  msg = tp_cm_message_new (base_conn, 1);
 
-  tp_message_set_handle (msg, 0, "message-sender", TP_HANDLE_TYPE_CONTACT,
-      priv->handle);
+  tp_cm_message_set_sender (msg, priv->handle);
 
   tp_message_set_uint32 (msg, 0, "message-type",
       TP_CHANNEL_TEXT_MESSAGE_TYPE_DELIVERY_REPORT);
@@ -793,7 +768,6 @@ rakia_text_channel_nua_r_message_cb (RakiaTextChannel *self,
 {
   RakiaTextChannelPrivate *priv = RAKIA_TEXT_CHANNEL_GET_PRIVATE (self);
   RakiaTextPendingMessage *msg;
-  TpHandleRepoIface *contact_repo;
   TpChannelTextSendError send_error;
   GList *node;
 
@@ -871,10 +845,7 @@ rakia_text_channel_nua_r_message_cb (RakiaTextChannel *self,
 
   g_queue_remove(priv->sending_messages, msg);
 
-  contact_repo = tp_base_connection_get_handles (
-      (TpBaseConnection *)(priv->conn), TP_HANDLE_TYPE_CONTACT);
-
-  rakia_text_pending_free(msg, contact_repo);
+  rakia_text_pending_free (msg);
 
   return TRUE;
 }
@@ -893,13 +864,12 @@ void rakia_text_channel_receive(RakiaTextChannel *chan,
   sip_date_t *hdr_date_sent;
 
   base_conn = (TpBaseConnection *) priv->conn;
-  msg = tp_message_new (base_conn, 2, 2);
+  msg = tp_cm_message_new (base_conn, 2);
 
   DEBUG ("Received message from contact %u: %s", sender, text);
 
   /* Header */
-  tp_message_set_handle (msg, 0, "message-sender", TP_HANDLE_TYPE_CONTACT,
-      sender);
+  tp_cm_message_set_sender (msg, sender);
   tp_message_set_int64 (msg, 0, "message-received", time (NULL));
 
   hdr_date_sent = sip_date (sip);
