@@ -397,7 +397,7 @@ rakia_text_manager_requestotron (RakiaTextManager *self,
 
   if (require_new)
     {
-      g_set_error (&error, TP_ERRORS, TP_ERROR_NOT_AVAILABLE,
+      g_set_error (&error, TP_ERROR, TP_ERROR_NOT_AVAILABLE,
           "Already chatting with contact #%u in another channel", handle);
       goto error;
     }
@@ -587,8 +587,6 @@ rakia_nua_i_message_cb (TpBaseConnection    *conn,
   rakia_text_channel_receive (channel,
       sip, handle, text, len);
 
-  rakia_handle_unref (conn, handle);
-
 end:
   g_free (allocated_text);
 
