@@ -64,7 +64,8 @@ priv_sip_to_url_make (RakiaConnection *conn,
 {
   const url_t *url;
 
-  url = rakia_handle_inspect_uri (TP_BASE_CONNECTION (conn), contact);
+  url = rakia_base_connection_handle_to_uri (
+      (RakiaBaseConnection *) conn, contact);
   return sip_to_create (home, (const url_string_t *) url);
 }
 
@@ -551,8 +552,8 @@ priv_stun_discover_cb (sres_context_t *ctx,
   RakiaConnection *conn = RAKIA_CONNECTION (ctx);
   RakiaConnectionPrivate *priv = RAKIA_CONNECTION_GET_PRIVATE (conn);
   sres_srv_record_t *sel = NULL;
-  int n_sel_items = 0;
-  int i;
+  guint n_sel_items = 0;
+  guint i;
 
   if (answers == NULL)
     return;
